@@ -262,12 +262,17 @@ class Dayline(graphics.Area):
             else:
                 if fact["start_time"].date() > dt.date.today() - dt.timedelta(days=1):
                     end_minutes = self._minutes_from_start(dt.datetime.now())
+                else:
+                    end_minutes = start_minutes
             
             if self.get_pixel(end_minutes) > 0 and \
                 self.get_pixel(start_minutes) < self.width:
                     context.set_source_rgba(0.86, 0.86, 0.86, 0.5)
-                    context.rectangle(self.get_pixel(start_minutes), graph_y,
-                                      self.get_pixel(end_minutes) - self.get_pixel(start_minutes), graph_height - 1)
+
+                    context.rectangle(round(self.get_pixel(start_minutes)),
+                                      graph_y,
+                                      round(self.get_pixel(end_minutes) - self.get_pixel(start_minutes)),
+                                      graph_height - 1)
                     context.fill()
                     context.stroke()
 
@@ -319,8 +324,8 @@ class Dayline(graphics.Area):
         
         #highlight rectangle
         if self.highlight:
-            self.highlight_start = self.get_pixel(self._minutes_from_start(self.highlight[0]))
-            self.highlight_end = self.get_pixel(self._minutes_from_start(self.highlight[1]))
+            self.highlight_start = round(self.get_pixel(self._minutes_from_start(self.highlight[0])))
+            self.highlight_end = round(self.get_pixel(self._minutes_from_start(self.highlight[1])))
 
         #TODO - make a proper range check here
         if self.highlight_end > 0 and self.highlight_start < self.width:
@@ -376,23 +381,34 @@ class CustomFactController:
             buf.set_text(fact["description"] or "")
             self.get_widget('description').set_buffer(buf)
 
-            if not end_date:
-                self.get_widget("in_progress").set_active(True)
-                if (dt.datetime.now() - start_date).days == 0:
-                    end_date = dt.datetime.now()
-
             self.get_widget("save_button").set_label("gtk-save")
             self.window.set_title(_("Update activity"))
 
-        elif fact_date and fact_date != dt.date.today():
+        else:
             # if there is previous activity with end time - attach to it
-            # otherwise let's start at 8am
+            # otherwise let's start at 8am (unless it is today - in that case
+            # we will assume that the user wants to start from this moment)
+            fact_date = fact_date or dt.date.today()
+
             last_activity = runtime.storage.get_facts(fact_date)
             if last_activity and last_activity[len(last_activity)-1]["end_time"]:
                 start_date = last_activity[len(last_activity)-1]["end_time"]
+
+                if fact_date != dt.date.today():
+                    end_date = start_date + dt.timedelta(minutes=30)
             else:
-                start_date = dt.datetime(fact_date.year, fact_date.month,
-                                         fact_date.day, 8)
+                if fact_date == dt.date.today():
+                    start_date = dt.datetime.now()
+                else:
+                    start_date = dt.datetime(fact_date.year, fact_date.month,
+                                             fact_date.day, 8)
+
+
+        if not end_date:
+            self.get_widget("in_progress").set_active(True)
+            if (dt.datetime.now() - start_date).days == 0:
+                end_date = dt.datetime.now()
+
 
         start_date = start_date or dt.datetime.now()
         end_date = end_date or start_date + dt.timedelta(minutes = 30)
