@@ -46,13 +46,11 @@ for module in (gettext, locale):
     if hasattr(module, 'bind_textdomain_codeset'):
         module.bind_textdomain_codeset('hamster-applet','UTF-8')
 
-
-from hamster.applet import HamsterApplet
-
 def applet_factory(applet, iid):
     applet.connect("destroy", on_destroy)
     applet.set_applet_flags(gnomeapplet.EXPAND_MINOR)
 
+    from hamster.applet import HamsterApplet    
     hamster_applet = HamsterApplet(applet)
 
     applet.show_all()
@@ -124,13 +122,13 @@ if __name__ == "__main__":
 
     elif start_window:
         if start_window == "stats":
-            from stats import StatsViewer
+            from hamster.stats import StatsViewer
             stats_viewer = StatsViewer().show()
         elif start_window == "edit":
-            from edit_activity import CustomFactController
+            from hamster.edit_activity import CustomFactController
             CustomFactController().show()
         elif start_window == "prefs":
-            from preferences import PreferencesEditor
+            from hamster.preferences import PreferencesEditor
             PreferencesEditor().show()
             
         gtk.main()
